@@ -14,12 +14,21 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-__version__ = '0.3'
+__version__ = '0.7'
 
 
 import os
 
 
+def cat(filename):
+    '''Return contents of file, or empty string if it doesn't exist.'''
+    if os.path.exists(filename):
+        with open(filename) as f:
+            return f.read()
+    else:
+        return ''
+
+
 class TestCase(object):
 
     def __init__(self, name, path_prefix):
